@@ -46,7 +46,7 @@ my @constants =
 our @EXPORT_OK = @constants;
 our @EXPORT = @constants;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -74,6 +74,7 @@ sub AUTOLOAD {
 require XSLoader;
 XSLoader::load('Audio::Opusfile', $VERSION);
 require Audio::Opusfile::Tags;
+require Audio::Opusfile::PictureTag;
 
 # Preloaded methods go here.
 
@@ -111,8 +112,8 @@ libopusfile is a library for decoding and basic manipulation of Ogg
 Opus files.
 
 Audio::Opusfile is an interface to libopusfile. At the moment its only
-function is reading tags from an Ogg Opus file. Future versions will
-give access to a larger part of the libopusfile API.
+function is reading metadata and tags from an Ogg Opus file. Future
+versions will give access to a larger part of the libopusfile API.
 
 Expect the API to change in future versions.
 
@@ -126,6 +127,10 @@ Creates a new Audio::Opusfile object from an Ogg Opus file.
 
 Dies if the given file does not exist or is not a valid Ogg Opus file.
 
+=item B<$of>->head
+
+Returns an L<Audio::Opusfile::Head> object corresponding to the file.
+
 =item B<$of>->tags
 
 Returns an L<Audio::Opusfile::Tags> object corresponding to the file.
